/// replication file- JHHPL R&R
// one dimension replication
use "heath_institutions_data", clear
label variable dimension_2 "Checks and Balance"
label variable healthwelfarefscale "Health/Welfare Scale"
label variable pollib_median "Policy Liberalism- CW"
label variable inst6017_nom "Policy Liberalism- Berry"
label variable pct_smoker "Percent Smoker"
label variable pct_insured "Proportion Insured"
label variable gini "Gini Index"
label variable partycontrol "Party Control"
xtset stateno year

********Time series dynamics****
gen infant_change=d.infant_mort
gen life_expchange=d.life_exp
gen mort_change=d.mortality

***Table 2
xtpcse d.infant_mort l.infant_mort d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 i.year
estimates store m1
xtpcse d.life_exp l.life_exp d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 i.year
estimates store m2
xtpcse d.mortality l.mortality d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 i.year
estimates store m3

esttab m1 m2 m3 , se label r2 drop(*.year) star(* .05 ** .01 *** .001) b(2) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Differenced Infant Mortality 1996-2016" "Differenced Life Expectancy 1975-2016" "Differenced Midlife Mortality 1999-2016") nogaps replace 

esttab m1 m2 m3 using ../models/table_2.rtf, r2 se label drop(*.year) star(* .05 ** .01 *** .001) b(2) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Differenced Infant Mortality 1996-2016" "Differenced Life Expectancy 1975-2016" "Differenced Midlife Mortality 1999-2016") nogaps replace 



*Table 3
estimates clear
reg infant_mort  dimension_1  dimension_2 i.stateno i.year, cluster(stateno)
estimates store m1
reg life_exp dimension_1  dimension_2 i.stateno i.year, cluster(stateno)
estimates store m2
reg mortality  dimension_1  dimension_2 i.stateno i.year, cluster(stateno)
estimates store m3


reg infant_mort  dimension_1  dimension_2 pollib_median partycontrol  i.stateno i.year, cluster(stateno)
estimates store m4
reg life_exp dimension_1  dimension_2  pollib_median  partycontrol i.stateno i.year, cluster(stateno)
estimates store m5
reg mortality  dimension_1  dimension_2  pollib_median  partycontrol i.stateno i.year, cluster(stateno)
estimates store m6

esttab m1 m2 m3 m4 m5 m6, se r2 label drop(*.year *.stateno) star(* .05 ** .01 *** .001) b(2) compress ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016" ///
"Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016") nogaps replace 

esttab m1 m2 m3 m4 m5 m6 using ../models/table_3.rtf,  se r2 label drop(*.year *.stateno) star(* .05 ** .01 *** .001) b(2) compress ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016" ///
"Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016") nogaps replace 



**Table 4
**Policy liberalism
estimates clear
xtpcse d.infant_mort l.infant_mort d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.dem_control d.dem_control i.year
estimates store m1
xtpcse d.life_exp l.life_exp d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.dem_control d.dem_control i.year
estimates store m2
xtpcse d.mortality l.mortality d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.dem_control d.dem_control i.year
estimates store m3

esttab m1 m2 m3 , se r2 label drop(*.year) star(* .05 ** .01 *** .001) b(2) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Differenced Infant Mortality 1996-2016" "Differenced Life Expectancy 1975-2016" "Differenced Midlife Mortality 1999-2016") nogaps replace 

esttab m1 m2 m3 using ../models/table_4.rtf,  se r2 label drop(*.year) star(* .05 ** .01 *** .001) b(2) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Differenced Infant Mortality 1996-2016" "Differenced Life Expectancy 1975-2016" "Differenced Midlife Mortality 1999-2016") nogaps replace 

*Table 5
**** Table 5
estimates clear
xtpcse d.infant_mort l.infant_mort d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.pct_smoker d.pct_smoker l.pct_insured d.pct_insured l.gini d.gini l.dem_control d.dem_control i.year
estimates store m25
xtpcse d.life_exp l.life_exp d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.pct_smoker d.pct_smoker l.pct_insured d.pct_insured l.gini d.gini l.dem_control d.dem_control i.year
estimates store m26
xtpcse d.mortality l.mortality d.dimension_1 l.dimension_1 d.dimension_2 l.dimension_2 l.pollib_median d.pollib_median l.pct_smoker d.pct_smoker l.pct_insured d.pct_insured l.gini d.gini l.dem_control d.dem_control i.year
estimates store m27



esttab m25 m26 m27, se r2 label drop(*year) b(3) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" ///
"Midlife Mortality 1999-2016") nogaps replace 

esttab m25 m26 m27 using ../models/table_5.rtf, se r2 label drop(*year) b(2) compress ///
rename(L.life_exp L.infant_mort L.mortality L.infant_mort)  ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" ///
"Midlife Mortality 1999-2016") nogaps replace 

*** Table 6
estimates clear
reg infant_mort  dimension_1  dimension_2 pollib_median pct_smoker pct_insured gini dem_control i.stateno i.year, cluster(stateno)
estimates store m31
reg life_exp dimension_1  dimension_2 pollib_median pct_smoker pct_insured gini dem_control i.stateno i.year, cluster(stateno)
estimates store m32
reg mortality  dimension_1  dimension_2 pollib_median pct_smoker pct_insured gini dem_control i.stateno i.year, cluster(stateno)
estimates store m33

esttab m31 m32 m33, se r2 label drop(*.year *.stateno) star(* .05 ** .01 *** .001) b(2) compress ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016") nogaps replace 


esttab m31 m32 m33 using ../models/table_6.rtf, se r2 label drop(*.year *.stateno) star(* .05 ** .01 *** .001) b(2) compress ///
mlabels("Infant Mortality 1996-2016" "Life Expectancy 1975-2016" "Midlife Mortality 1999-2016") nogaps replace 



